CVS: sylpheedclaws/sylpheed-claws/src Makefile.am,1.155.2.43.2.1,1.155.2.43.2.2 addr_compl.c,1.27.2.23.2.1,1.27.2.23.2.2 compose.c,1.382.2.321.2.8,1.382.2.321.2.9 crash.c,1.23.2.17.8.1,1.23.2.17.8.2 export.c,1.8.2.20.2.1,1.8.2.20.2.2 exporthtml.c,1.5.2.13.6.1,1.5.2.13.6.2 exportldif.c,1.1.4.11.6.1,1.1.4.11.6.2 imap.c,1.179.2.137.2.1,1.179.2.137.2.2 import.c,1.13.2.18.4.1,1.13.2.18.4.2 main.c,1.115.2.110.2.1,1.115.2.110.2.2 main.h,1.7.2.4.4.1,1.7.2.4.4.2 matcher.c,1.75.2.31.4.1,1.75.2.31.4.2 mimeview.c,1.83.2.91.2.1,1.83.2.91.2.2 procmsg.c,1.150.2.81.2.1,1.150.2.81.2.2

[email protected]
Newsgroups gmane.mail.sylpheed.claws.cvs
Message-ID <[email protected]>
Update of /pack/anoncvs/sylpheedclaws/sylpheed-claws/src
In directory sunsite.dk:/tmp/cvs-serv28725/src

Modified Files:
      Tag: stable_2_6
	Makefile.am addr_compl.c compose.c crash.c export.c 
	exporthtml.c exportldif.c imap.c import.c main.c main.h 
	matcher.c mimeview.c procmsg.c 
Log Message:
2006-12-04 [paul]	2.6.0cvs25-stable

	* ChangeLog
	* Makefile.am
	* configure.ac
	* m4/aclocal-include.m4
	* m4/check-type.m4
	* src/Makefile.am
	* src/addr_compl.c
	* src/compose.c
	* src/crash.c
	* src/export.c
	* src/exporthtml.c
	* src/exportldif.c
	* src/imap.c
	* src/import.c
	* src/main.c
	* src/main.h
	* src/matcher.c
	* src/mimeview.c
	* src/procmsg.c
	* src/common/Makefile.am
	* src/common/claws.c
	* src/common/claws.h
	* src/common/ssl.c
	* src/common/sylpheed.c
	* src/common/sylpheed.h
	* src/etpan/Makefile.am
	* src/gtk/Makefile.am
	* src/gtk/claws-marshal.list
	* src/gtk/filesel.c
	* src/gtk/gtksctree.c
	* src/gtk/quicksearch.c
	* src/gtk/sylpheed-marshal.list
	* src/plugins/bogofilter/bogofilter.c
	* src/plugins/bogofilter/bogofilter_gtk.c
	* src/plugins/clamav/clamav_plugin.c
	* src/plugins/clamav/clamav_plugin_gtk.c
	* src/plugins/demo/demo.c
	* src/plugins/dillo_viewer/dillo_viewer.c
	* src/plugins/pgpcore/Makefile.am
	* src/plugins/pgpcore/claws.def
	* src/plugins/pgpcore/pgp_viewer.c
	* src/plugins/pgpcore/plugin.c
	* src/plugins/pgpcore/sylpheed.def
	* src/plugins/pgpinline/Makefile.am
	* src/plugins/pgpinline/claws.def
	* src/plugins/pgpinline/plugin.c
	* src/plugins/pgpinline/sylpheed.def
	* src/plugins/pgpmime/Makefile.am
	* src/plugins/pgpmime/claws.def
	* src/plugins/pgpmime/plugin.c
	* src/plugins/pgpmime/sylpheed.def
	* src/plugins/spamassassin/spamassassin.c
	* src/plugins/spamassassin/spamassassin_gtk.c
	* src/plugins/trayicon/trayicon.c
		backport from 2.6.0cvs64:
		yet more renaming 

Index: Makefile.am
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/Makefile.am,v
retrieving revision 1.155.2.43.2.1
retrieving revision 1.155.2.43.2.2
diff -u -d -r1.155.2.43.2.1 -r1.155.2.43.2.2
--- Makefile.am	2006/11/24 13:10:22	1.155.2.43.2.1
+++ Makefile.am	2006/12/04 14:21:49	1.155.2.43.2.2
@@ -1,7 +1,7 @@
 
-if SYLPHEED_LIBETPAN
+if CLAWS_LIBETPAN
 etpan_dir = etpan
-etpan_library = etpan/libsylpheedetpan.la
+etpan_library = etpan/libclawsetpan.la
 else
 etpan_dir =
 etpan_library = 
@@ -423,7 +423,7 @@
 
 claws_mail_LDADD = \
 	$(etpan_library) \
-	gtk/libsylpheedgtk.la \
+	gtk/libclawsgtk.la \
 	$(ASPELL_LIBS) \
 	$(INTLLIBS) \
 	$(GTK_LIBS) \
@@ -466,7 +466,7 @@
 	@rm -f claws-mail$(EXEEXT)
 	@rm -f claws-mail.def claws-mail.base claws-mail.exp libclaws-mail.a .libs/libclaws-mail.a
 	$(LINK) -shared $(claws_mailLDFLAGS) -Wl,--out-implib=libclaws-mail.a -Wl,--export-all-symbols,--exclude-symbols,main $(claws_mail_OBJECTS) -Wl,--no-whole-archive $(claws_mail_LDADD) $(LIBS)
-	dlltool --output-def claws-mail.def --dllname claws-mail$(EXEEXT) --export-all-symbols --exclude-symbols main $(claws_mail_OBJECTS) gtk/.libs/libsylpheedgtk.a
+	dlltool --output-def claws-mail.def --dllname claws-mail$(EXEEXT) --export-all-symbols --exclude-symbols main $(claws_mail_OBJECTS) gtk/.libs/libclawsgtk.a
 	$(LINK) $(claws_mail_LDFLAGS) -Wl,--base-file,claws-mail.base $(claws_mail_OBJECTS) $(claws_mail_LDADD) $(LIBS)
 	sleep 5
 	dlltool --base-file claws-mail.base --input-def claws-mail.def --output-exp claws-mail.exp

Index: compose.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/compose.c,v
retrieving revision 1.382.2.321.2.8
retrieving revision 1.382.2.321.2.9
diff -u -d -r1.382.2.321.2.8 -r1.382.2.321.2.9
--- compose.c	2006/12/01 12:37:51	1.382.2.321.2.8
+++ compose.c	2006/12/04 14:21:49	1.382.2.321.2.9
@@ -81,7 +81,7 @@
 #  include <wctype.h>
 #endif
 
-#include "sylpheed.h"
+#include "claws.h"
 #include "main.h"
 #include "mainwindow.h"
 #include "compose.h"

Index: export.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/export.c,v
retrieving revision 1.8.2.20.2.1
retrieving revision 1.8.2.20.2.2
diff -u -d -r1.8.2.20.2.1 -r1.8.2.20.2.2
--- export.c	2006/11/24 13:10:53	1.8.2.20.2.1
+++ export.c	2006/12/04 14:21:53	1.8.2.20.2.2
@@ -38,7 +38,7 @@
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtksignal.h>
 
-#include "sylpheed.h"
+#include "claws.h"
 #include "main.h"
 #include "inc.h"
 #include "mbox.h"
@@ -82,7 +82,7 @@
 		gtk_widget_show(window);
 	}
 
-	change_dir(sylpheed_get_startup_dir());
+	change_dir(claws_get_startup_dir());
 
 	if (default_src && default_src->path) {
 		src_id = folder_item_get_identifier(default_src);

Index: exporthtml.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/exporthtml.c,v
retrieving revision 1.5.2.13.6.1
retrieving revision 1.5.2.13.6.2
diff -u -d -r1.5.2.13.6.1 -r1.5.2.13.6.2
--- exporthtml.c	2006/11/24 13:10:53	1.5.2.13.6.1
+++ exporthtml.c	2006/12/04 14:21:53	1.5.2.13.6.2
@@ -43,8 +43,8 @@
 #define mkdir(a,b) mkdir(a)
 #endif
 
-#define DFL_DIR_SYLPHEED_OUT  "sylpheed-out"
-#define DFL_FILE_SYLPHEED_OUT "addressbook.html"
+#define DFL_DIR_CLAWS_OUT  "claws-mail-out"
+#define DFL_FILE_CLAWS_OUT "addressbook.html"
 
 #define FMT_BUFSIZE         2048
 #define SC_HTML_SPACE          "&nbsp;"
@@ -55,7 +55,7 @@
 
 /* Stylesheet names */
 #define FILENAME_NONE       ""
-#define FILENAME_DEFAULT    "sylpheed.css"
+#define FILENAME_DEFAULT    "claws-mail.css"
 #define FILENAME_FULL       "full.css"
 #define FILENAME_CUSTOM     "custom.css"
 #define FILENAME_CUSTOM2    "custom2.css"
@@ -1144,13 +1144,13 @@
 
 	str = g_strconcat(
 		get_home_dir(), G_DIR_SEPARATOR_S,
-		DFL_DIR_SYLPHEED_OUT, NULL );
+		DFL_DIR_CLAWS_OUT, NULL );
 
 	ctl->dirOutput = mgu_replace_string( ctl->dirOutput, str );
 	g_free( str );
 
 	ctl->fileHtml =
-		mgu_replace_string( ctl->fileHtml, DFL_FILE_SYLPHEED_OUT );
+		mgu_replace_string( ctl->fileHtml, DFL_FILE_CLAWS_OUT );
 	ctl->encoding = NULL;
 	ctl->stylesheet = EXPORT_HTML_ID_DEFAULT;
 	ctl->nameFormat = EXPORT_HTML_FIRST_LAST;

Index: exportldif.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/exportldif.c,v
retrieving revision 1.1.4.11.6.1
retrieving revision 1.1.4.11.6.2
diff -u -d -r1.1.4.11.6.1 -r1.1.4.11.6.2
--- exportldif.c	2006/11/24 13:10:54	1.1.4.11.6.1
+++ exportldif.c	2006/12/04 14:21:54	1.1.4.11.6.2
@@ -44,8 +44,8 @@
 #define mkdir(a,b) mkdir(a)
 #endif
 
-#define DFL_DIR_SYLPHEED_OUT  "sylpheed-out"
-#define DFL_FILE_SYLPHEED_OUT "addressbook.ldif"
+#define DFL_DIR_CLAWS_OUT  "claws-mail-out"
+#define DFL_FILE_CLAWS_OUT "addressbook.ldif"
 
 #define FMT_BUFSIZE           2048
 #define XML_BUFSIZE           2048
@@ -621,13 +621,13 @@
 
 	str = g_strconcat(
 		get_home_dir(), G_DIR_SEPARATOR_S,
-		DFL_DIR_SYLPHEED_OUT, NULL );
+		DFL_DIR_CLAWS_OUT, NULL );
 
 	ctl->dirOutput = mgu_replace_string( ctl->dirOutput, str );
 	g_free( str );
 
 	ctl->fileLdif =
-		mgu_replace_string( ctl->fileLdif, DFL_FILE_SYLPHEED_OUT );
+		mgu_replace_string( ctl->fileLdif, DFL_FILE_CLAWS_OUT );
 	ctl->suffix = mgu_replace_string( ctl->suffix, "" );
 
 	ctl->rdnIndex = EXPORT_LDIF_ID_UID;

Index: imap.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/imap.c,v
retrieving revision 1.179.2.137.2.1
retrieving revision 1.179.2.137.2.2
diff -u -d -r1.179.2.137.2.1 -r1.179.2.137.2.2
--- imap.c	2006/11/24 13:11:06	1.179.2.137.2.1
+++ imap.c	2006/12/04 14:21:54	1.179.2.137.2.2
@@ -64,7 +64,7 @@
 #include "log.h"
 #include "remotefolder.h"
 #include "alertpanel.h"
-#include "sylpheed.h"
+#include "claws.h"
 #include "statusbar.h"
 #include "msgcache.h"
 #include "imap-thread.h"
@@ -389,7 +389,7 @@
 static MsgInfo *imap_parse_msg(const gchar *file, FolderItem *item);
 
 
-/* data types conversion libetpan <-> sylpheed */
+/* data types conversion libetpan <-> claws */
 static GSList * imap_list_from_lep(IMAPFolder * folder,
 				   clist * list, const gchar * real_path, gboolean all);
 static GSList * imap_get_lep_set_from_numlist(MsgNumberList *numlist);
@@ -4016,7 +4016,7 @@
 
 
 
-/* data types conversion libetpan <-> sylpheed */
+/* data types conversion libetpan <-> claws */
 
 
 

Index: import.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/import.c,v
retrieving revision 1.13.2.18.4.1
retrieving revision 1.13.2.18.4.2
diff -u -d -r1.13.2.18.4.1 -r1.13.2.18.4.2
--- import.c	2006/11/24 13:11:09	1.13.2.18.4.1
+++ import.c	2006/12/04 14:21:55	1.13.2.18.4.2
@@ -38,7 +38,7 @@
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtksignal.h>
 
-#include "sylpheed.h"
+#include "claws.h"
 #include "main.h"
 #include "inc.h"
 #include "mbox.h"
@@ -82,7 +82,7 @@
 		gtk_widget_show(window);
 	}
 
-	change_dir(sylpheed_get_startup_dir());
+	change_dir(claws_get_startup_dir());
 
 	if (default_dest && default_dest->path) {
 		dest_id = folder_item_get_identifier(default_dest);

Index: main.h
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/main.h,v
retrieving revision 1.7.2.4.4.1
retrieving revision 1.7.2.4.4.2
diff -u -d -r1.7.2.4.4.1 -r1.7.2.4.4.2
--- main.h	2006/11/24 13:11:19	1.7.2.4.4.1
+++ main.h	2006/12/04 14:21:56	1.7.2.4.4.2
@@ -28,6 +28,6 @@
 
 void app_will_exit	(GtkWidget *widget, gpointer data);
 gboolean clean_quit	(gpointer data);
-gboolean sylpheed_is_exiting(void);
+gboolean claws_is_exiting(void);
 
 #endif /* __MAIN_H__ */

Index: matcher.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/matcher.c,v
retrieving revision 1.75.2.31.4.1
retrieving revision 1.75.2.31.4.2
diff -u -d -r1.75.2.31.4.1 -r1.75.2.31.4.2
--- matcher.c	2006/11/24 13:11:21	1.75.2.31.4.1
+++ matcher.c	2006/12/04 14:21:56	1.75.2.31.4.2
@@ -41,7 +41,7 @@
 #include "addr_compl.h"
 #include "codeconv.h"
 #include "quoted-printable.h"
-#include "sylpheed.h"
+#include "claws.h"
 #include <ctype.h>
 
 /*!
@@ -507,7 +507,7 @@
 		printf("waiting for test thread\n");
 		while(!td->done) {
 			/* don't let the interface freeze while waiting */
-			sylpheed_do_idle();
+			claws_do_idle();
 			if (time(NULL) - start_time > 30) {
 				pthread_cancel(pt);
 				td->done = TRUE;

Index: mimeview.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/mimeview.c,v
retrieving revision 1.83.2.91.2.1
retrieving revision 1.83.2.91.2.2
diff -u -d -r1.83.2.91.2.1 -r1.83.2.91.2.2
--- mimeview.c	2006/11/24 13:11:26	1.83.2.91.2.1
+++ mimeview.c	2006/12/04 14:21:56	1.83.2.91.2.2
@@ -283,7 +283,6 @@
  	popupmenu = menu_create_items(mimeview_popup_entries, n_entries,
  				      "<MimeView>", &popupfactory, mimeview);
 	tooltips = gtk_tooltips_new();
-	gtk_tooltips_set_delay(tooltips, 0); 
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox);

Index: procmsg.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/procmsg.c,v
retrieving revision 1.150.2.81.2.1
retrieving revision 1.150.2.81.2.2
diff -u -d -r1.150.2.81.2.1 -r1.150.2.81.2.2
--- procmsg.c	2006/11/24 13:11:54	1.150.2.81.2.1
+++ procmsg.c	2006/12/04 14:21:57	1.150.2.81.2.2
@@ -65,7 +65,7 @@
 	Q_PRIVACY_SYSTEM   = 9,
 	Q_ENCRYPT 	   = 10,
 	Q_ENCRYPT_DATA	   = 11,
-	Q_SYLPHEED_HDRS    = 12,
+	Q_CLAWS_HDRS    = 12,
 };
 
 GHashTable *procmsg_msg_hash_table_create(GSList *mlist)
@@ -1550,7 +1550,7 @@
 			if (encrypt_data == NULL) 
 				encrypt_data = g_strdup(p);
 			break;
-		case Q_SYLPHEED_HDRS:
+		case Q_CLAWS_HDRS:
 			/* end of special headers reached */
 			goto send_mail; /* can't "break;break;" */
 		}
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
Index: addr_compl.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/addr_compl.c,v
retrieving revision 1.27.2.23.2.1
retrieving revision 1.27.2.23.2.2
diff -u -d -r1.27.2.23.2.1 -r1.27.2.23.2.2
--- addr_compl.c	2006/11/24 13:10:24	1.27.2.23.2.1
+++ addr_compl.c	2006/12/04 14:21:49	1.27.2.23.2.2
@@ -46,7 +46,7 @@
 #include "addr_compl.h"
 #include "utils.h"
 #include "prefs_common.h"
-#include "sylpheed.h"
+#include "claws.h"
 #include <pthread.h>
 
 /*!
@@ -661,7 +661,7 @@
 
 /*
  * address completion entry ui. the ui (completion list was inspired by galeon's
  * auto completion list). remaining things powered by sylpheed's completion engine.
  */
 
 #define ENTRY_DATA_TAB_HOOK	"tab_hook"	/* used to lookup entry */
@@ -909,7 +909,7 @@
 		_displayQueue_ = NULL;
 	}
 	pthread_mutex_unlock( & _completionMutex_ );
-	sylpheed_do_idle();
+	claws_do_idle();
 
 	return TRUE;
 }
@@ -661,7 +661,7 @@
 /*
  * address completion entry ui. the ui (completion list was inspired by galeon's
- * auto completion list). remaining things powered by sylpheed's completion engine.
+ * auto completion list). remaining things powered by claws's completion engine.
  */
 

Index: crash.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/crash.c,v
retrieving revision 1.23.2.17.8.1
retrieving revision 1.23.2.17.8.2
diff -u -d -r1.23.2.17.8.1 -r1.23.2.17.8.2
--- crash.c	2006/11/24 13:10:43	1.23.2.17.8.1
+++ crash.c	2006/12/04 14:21:53	1.23.2.17.8.2
@@ -49,7 +49,7 @@
 #ifdef SIGTERM
 #include "main.h"
 #endif
-#include "sylpheed.h"
+#include "claws.h"
 #include "crash.h"
 #include "utils.h"
 #include "filesel.h"
@@ -57,7 +57,7 @@
 #include "prefs_common.h"
 
 /*
  * NOTE: the crash dialog is called when sylpheed is not 
  * initialized, so do not assume settings are available.
  * for example, loading / creating pixmaps seems not 
  * to be possible.
@@ -282,7 +282,7 @@
 
 
 /*!
  *\brief	create debugger script file in sylpheed directory.
  *		all the other options (creating temp files) looked too 
  *		convoluted.
  */
@@ -322,7 +322,7 @@
 }
 
 /*!
  *\brief	launches debugger and attaches it to crashed sylpheed
  */
 static void crash_debug(unsigned long crash_pid, 
 			gchar *exe_image,
@@ -342,7 +342,7 @@
 		setuid(getuid());
 
 		/*
 		 * setup debugger to attach to crashed sylpheed
 		 */
 		*argptr++ = "gdb"; 
 		*argptr++ = "--nw";
@@ -537,7 +537,7 @@
 		args[3] = buf;
 		args[4] = NULL;
 
-		chdir(sylpheed_get_startup_dir());
+		chdir(claws_get_startup_dir());
 		setgid(getgid());
 		setuid(getuid());
 		execvp(argv0, args);
@@ -57,7 +57,7 @@
 
 /*
- * NOTE: the crash dialog is called when sylpheed is not 
+ * NOTE: the crash dialog is called when claws is not 
  * initialized, so do not assume settings are available.
  * for example, loading / creating pixmaps seems not 
@@ -282,7 +282,7 @@
 
 /*!
- *\brief	create debugger script file in sylpheed directory.
+ *\brief	create debugger script file in claws directory.
  *		all the other options (creating temp files) looked too 
  *		convoluted.
@@ -322,7 +322,7 @@
 
 /*!
- *\brief	launches debugger and attaches it to crashed sylpheed
+ *\brief	launches debugger and attaches it to crashed claws
  */
 static void crash_debug(unsigned long crash_pid, 
@@ -342,7 +342,7 @@
 
 		/*
-		 * setup debugger to attach to crashed sylpheed
+		 * setup debugger to attach to crashed claws
 		 */
 		*argptr++ = "gdb"; 

Index: main.c
===================================================================
RCS file: /pack/anoncvs/sylpheedclaws/sylpheed-claws/src/main.c,v
retrieving revision 1.115.2.110.2.1
retrieving revision 1.115.2.110.2.2
diff -u -d -r1.115.2.110.2.1 -r1.115.2.110.2.2
--- main.c	2006/11/24 13:11:18	1.115.2.110.2.1
+++ main.c	2006/12/04 14:21:55	1.115.2.110.2.2
@@ -51,7 +51,7 @@
 # include <gdk/gdkx.h>
 #endif
 
-#include "sylpheed.h"
+#include "claws.h"
 #include "main.h"
 #include "mainwindow.h"
 #include "folderview.h"
@@ -170,7 +170,7 @@
 static void initial_processing		(FolderItem *item, gpointer data);
 static void quit_signal_handler         (int sig);
 static void install_basic_sighandlers   (void);
-static void exit_sylpheed		(MainWindow *mainwin);
+static void exit_claws			(MainWindow *mainwin);
 
 #define MAKE_DIR_IF_NOT_EXIST(dir) \
 { \
@@ -234,7 +234,7 @@
 }
 #endif /* HAVE_STARTUP_NOTIFICATION */
 
-void sylpheed_gtk_idle(void) 
+void claws_gtk_idle(void) 
 {
 	while(gtk_events_pending()) {
 		gtk_main_iteration();
@@ -511,7 +511,7 @@
 	gint num_folder_class = 0;
 	START_TIMING("startup");
 	
-	if (!sylpheed_init(&argc, &argv)) {
+	if (!claws_init(&argc, &argv)) {
 		return 0;
 	}
 
@@ -729,7 +729,7 @@
 			exit(1);
 		account_read_config_all();
 		if(!account_get_list())
-			exit_sylpheed(mainwin);
+			exit_claws(mainwin);
 	}
 
 	
@@ -747,11 +747,11 @@
 
 	prefs_matcher_read_config();
 
 	/* make one all-folder processing before using sylpheed */
 	main_window_cursor_wait(mainwin);
 	folder_func_to_all_folders(initial_processing, (gpointer *)mainwin);
 
-	/* if Sylpheed crashed, rebuild caches */
+	/* if claws crashed, rebuild caches */
 	if (!cmd.crash && crash_file_present) {
 		GTK_EVENTS_FLUSH();
 		debug_print("Claws Mail crashed, checking for new messages in local folders\n");
@@ -785,7 +785,7 @@
 		cmd.status_full_folders = NULL;
 	}
 
-	sylpheed_register_idle_function(sylpheed_gtk_idle);
+	claws_register_idle_function(claws_gtk_idle);
 
 	prefs_toolbar_init();
 
@@ -865,7 +865,7 @@
 	END_TIMING();
 	gtk_main();
 
-	exit_sylpheed(mainwin);
+	exit_claws(mainwin);
 
 	return 0;
 }
@@ -884,7 +884,7 @@
 
 static gboolean sc_exiting = FALSE;
 
-static void exit_sylpheed(MainWindow *mainwin)
+static void exit_claws(MainWindow *mainwin)
 {
 	gchar *filename;
 
@@ -967,7 +967,7 @@
 	gtkaspell_checkers_quit();
 #endif
 	plugin_unload_all("Common");
-	sylpheed_done();
+	claws_done();
 }
 
 static void parse_cmd_opt(int argc, char *argv[])
@@ -1007,7 +1007,7 @@
 					cmd.attach_files = g_ptr_array_new();
 				}
 				if (*p != G_DIR_SEPARATOR) {
-					file = g_strconcat(sylpheed_get_startup_dir(),
+					file = g_strconcat(claws_get_startup_dir(),
 							   G_DIR_SEPARATOR_S,
 							   p, NULL);
 				} else {
@@ -1190,7 +1190,7 @@
 		
 	draft_all_messages();
 	emergency_exit = TRUE;
-	exit_sylpheed(static_mainwindow);
+	exit_claws(static_mainwindow);
 	exit(0);
 
 	return FALSE;
@@ -1240,7 +1240,7 @@
 	gtk_main_quit();
 }
 
-gboolean sylpheed_is_exiting(void)
+gboolean claws_is_exiting(void)
 {
 	return sc_exiting;
 }
@@ -747,11 +747,11 @@
 	prefs_matcher_read_config();
 
-	/* make one all-folder processing before using sylpheed */
+	/* make one all-folder processing before using claws */
 	main_window_cursor_wait(mainwin);
 	folder_func_to_all_folders(initial_processing, (gpointer *)mainwin);
